<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns="http://www.w3.org/1999/xhtml"
                              xmlns:html="http://www.w3.org/1999/xhtml"
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                              xmlns:wwmode="urn:WebWorks-Engine-Mode"
                              xmlns:wwdoc="urn:WebWorks-Document-Schema"
                              xmlns:wwsplits="urn:WebWorks-Engine-Splits-Schema"
                              xmlns:wwproject="urn:WebWorks-Publish-Project"
                              xmlns:wwlog="urn:WebWorks-XSLT-Extension-Log"
                              xmlns:wwprojext="urn:WebWorks-XSLT-Extension-Project"
                              xmlns:wwunits="urn:WebWorks-XSLT-Extension-Units"
                              xmlns:wwexsldoc="urn:WebWorks-XSLT-Extension-Document"
                              exclude-result-prefixes="xsl msxsl wwmode wwdoc wwproject wwlog wwprojext wwunits wwexsldoc"
>
 <xsl:import href="wwtransform:super" />


 <xsl:template match="wwdoc:Paragraph[@stylename = 'ErrorList2']" mode="wwmode:content">
  <xsl:param name="ParamSplits" />
  <xsl:param name="ParamCargo" />
  <xsl:param name="ParamLinks" />
  <xsl:param name="ParamTOCData" />
  <xsl:param name="ParamSplit" />

  <xsl:variable name="VarParagraph" select="." />

  <!-- Inspect paragraph info -->
  <!--                        -->
  <xsl:variable name="VarContextRule" select="wwprojext:GetContextRule('Paragraph', $VarParagraph/@stylename, $ParamSplit/@documentID, $VarParagraph/@id)" />

  <!-- Resolve project properties -->
  <!--                            -->
  <xsl:variable name="VarResolvedContextPropertiesAsXML">
   <xsl:call-template name="Properties-ResolveContextRule">
    <xsl:with-param name="ParamDocumentContext" select="$VarParagraph" />
    <xsl:with-param name="ParamProperties" select="$VarContextRule/wwproject:Properties/wwproject:Property" />
    <xsl:with-param name="ParamStyleName" select="$VarParagraph/@stylename" />
    <xsl:with-param name="ParamStyleType" select="'Paragraph'" />
    <xsl:with-param name="ParamContextStyle" select="$VarParagraph/wwdoc:Style" />
   </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="VarResolvedContextProperties" select="msxsl:node-set($VarResolvedContextPropertiesAsXML)/wwproject:Property" />

  <!-- CSS properties -->
  <!--                -->
  <xsl:variable name="VarCSSContextPropertiesAsXML">
   <xsl:call-template name="CSS-TranslateProjectProperties">
    <xsl:with-param name="ParamProperties" select="$VarResolvedContextProperties" />
    <xsl:with-param name="ParamFromAbsoluteURI" select="$ParamSplit/@path" />
    <xsl:with-param name="ParamSplits" select="$ParamSplits" />
   </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="VarCSSContextProperties" select="msxsl:node-set($VarCSSContextPropertiesAsXML)/wwproject:Property" />

  <!-- Collect non-empty text runs -->
  <!--                             -->
  <xsl:variable name="VarTextRuns" select="$VarParagraph/wwdoc:TextRun[count(child::wwdoc:Text[1] | child::wwdoc:Frame[1] | child::wwdoc:Note[1] | child::wwdoc:LineBreak[1] | child::wwdoc:Marker[1]) &gt; 0]" />

  <!-- Emit as table -->
  <!--               -->
  <html:table>
   <html:tr>
    <html:td>
     <xsl:attribute name="style">
      <xsl:text>vertical-align: baseline;</xsl:text>

      <!-- Set width equal to paragraph's text indent? -->
      <!--                                             -->
      <xsl:variable name="VarTextIndent">
       <!-- Text indent defined? -->
       <!--                      -->
       <xsl:variable name="VarContextTextIndent" select="$VarCSSContextProperties[@Name = 'text-indent']/@Value" />
       <xsl:if test="string-length($VarContextTextIndent) &gt; 0">
        <xsl:value-of select="$VarContextTextIndent" />
       </xsl:if>
      </xsl:variable>
      <xsl:variable name="VarTextIndentNumericPrefix" select="wwunits:NumericPrefix($VarTextIndent)" />
      <xsl:variable name="VarTextIndentLessThanZero" select="(string-length($VarTextIndentNumericPrefix) &gt; 0) and (number($VarTextIndentNumericPrefix) &lt; 0)" />
      <xsl:if test="$VarTextIndentLessThanZero">
       <xsl:variable name="VarTextIndentNumberAsUnits" select="wwunits:NumericPrefix($VarTextIndent)" />
       <xsl:variable name="VarTextIndentUnits" select="wwunits:UnitsSuffix($VarTextIndent)" />

       <!-- width and whitespace -->
       <!--                      -->
       <xsl:text> width: </xsl:text>
       <xsl:value-of select="0 - $VarTextIndentNumberAsUnits" />
       <xsl:value-of select="$VarTextIndentUnits" />
       <xsl:text>; white-space: nowrap</xsl:text>
      </xsl:if>
     </xsl:attribute>

     <!-- First text run -->
     <!--                -->
     <xsl:for-each select="$VarTextRuns[1]">
      <xsl:variable name="VarTextRun" select="." />

      <!-- Eliminate tabs -->
      <!--                -->
      <wwexsldoc:MappingContext>
       <wwexsldoc:MapEntry match="&#9;"></wwexsldoc:MapEntry>

       <!-- Emit text -->
       <!--           -->
       <xsl:call-template name="TextRun">
        <xsl:with-param name="ParamSplits" select="$ParamSplits" />
        <xsl:with-param name="ParamCargo" select="$ParamCargo" />
        <xsl:with-param name="ParamLinks" select="$ParamLinks" />
        <xsl:with-param name="ParamSplit" select="$ParamSplit" />
        <xsl:with-param name="ParamParagraphID" select="$VarParagraph/@id" />
        <xsl:with-param name="ParamUseCharacterStyles" select="true()" />
        <xsl:with-param name="ParamTextRun" select="$VarTextRun" />
        <xsl:with-param name="ParamEmitAnchorName" select="true()" />
       </xsl:call-template>
      </wwexsldoc:MappingContext>
     </xsl:for-each>
    </html:td>

    <html:td style="vertical-align: baseline">
     <!-- Remaining text runs -->
     <!--                     -->
     <xsl:for-each select="$VarTextRuns[1]/following-sibling::wwdoc:TextRun">
      <xsl:variable name="VarTextRun" select="." />

      <!-- Eliminate tabs -->
      <!--                -->
      <wwexsldoc:MappingContext>
       <wwexsldoc:MapEntry match="&#9;"></wwexsldoc:MapEntry>

       <!-- Emit text -->
       <!--           -->
       <xsl:call-template name="TextRun">
        <xsl:with-param name="ParamSplits" select="$ParamSplits" />
        <xsl:with-param name="ParamCargo" select="$ParamCargo" />
        <xsl:with-param name="ParamLinks" select="$ParamLinks" />
        <xsl:with-param name="ParamSplit" select="$ParamSplit" />
        <xsl:with-param name="ParamParagraphID" select="$VarParagraph/@id" />
        <xsl:with-param name="ParamUseCharacterStyles" select="true()" />
        <xsl:with-param name="ParamTextRun" select="$VarTextRun" />
        <xsl:with-param name="ParamEmitAnchorName" select="false()" />
       </xsl:call-template>
      </wwexsldoc:MappingContext>
     </xsl:for-each>
    </html:td>
   </html:tr>
  </html:table> </xsl:template>
</xsl:stylesheet>
